@@ -1,5 +1,5 @@
+"""HTTP Client library"""
 import json
-import encodings.idna
 
 
 try:
@@ -13,23 +13,23 @@ except ImportError:
 
 
 class Client(object):
-    """Quickly and easily access any REST or REST-like API.
-
-    :param host: Base URL for the api. (e.g. https://api.sendgrid.com)
-    :type host:  string
-    :param request_headers: A dictionary of the headers you want
-                            applied on all calls
-    :type request_headers: dictionary
-    :param version: The version number of the API.
-                    Subclass _build_versioned_url for custom behavior.
-                    Or just pass the version as part of the URL
-                    (e.g. client._('/v3'))
-    :type integer:
-    """
+    """Quickly and easily access any REST or REST-like API."""
     def __init__(self,
                  host,
                  request_headers=None,
                  version=None):
+        """
+        :param host: Base URL for the api. (e.g. https://api.sendgrid.com)
+        :type host:  string
+        :param request_headers: A dictionary of the headers you want
+                                applied on all calls
+        :type request_headers: dictionary
+        :param version: The version number of the API.
+                        Subclass _build_versioned_url for custom behavior.
+                        Or just pass the version as part of the URL
+                        (e.g. client._("/v3"))
+        :type integer:
+        """
         self.host = host
         self.request_headers = request_headers
         # These are the supported HTTP verbs
@@ -43,34 +43,38 @@ class Client(object):
         self._response_headers = None
         self._response = None
 
-    """Resets the URL builder, so you can make a fresh new dynamic call."""
     def _reset(self):
+        """Resets the URL builder, so you can make a fresh new dynamic call."""
         self._count = 0
         self._url_path = {}
         self._response = None
 
-    """Takes the method chained call and adds to the url path.
-
-       :param name: The name of the method call
-       :type name: string
-    """
     def _add_to_url_path(self, name):
+        """Takes the method chained call and adds to the url path.
+
+           :param name: The name of the method call
+           :type name: string
+        """
         self._url_path[self._count] = name
         self._count += 1
 
-    """Subclass this function for your own needs.
-       Or just pass the version as part of the URL
-       (e.g. client._('/v3'))
-    """
     def _build_versioned_url(self, url):
+        """Subclass this function for your own needs.
+           Or just pass the version as part of the URL
+           (e.g. client._('/v3'))
+        :param url: URI portion of the full URL being requested
+        :type url: string
+        :return:
+        """
         return '{0}/v{1}{2}'.format(self.host, str(self._version), url)
 
-    """Build the final URL to be passed to urllib
-
-    :param query_params: A dictionary of all the query parameters
-    :type query_params: dictionary
-    """
     def _build_url(self, query_params):
+        """Build the final URL to be passed to urllib
+
+        :param query_params: A dictionary of all the query parameters
+        :type query_params: dictionary
+        :return:
+        """
         url = ''
         count = 0
         while count < len(self._url_path):
@@ -85,54 +89,69 @@ class Client(object):
             url = self.host + url
         return url
 
-    """Build the API call's response
-
-    :param response: The response object from the API call from urllib
-    :type response: urllib.Request object
-    """
     def _set_response(self, response):
+        """Build the API call's response
+
+        :param response: The response object from the API call from urllib
+        :type response: urllib.Request object
+        """
         self._status_code = response.getcode()
         self._response_body = response.read()
         self._response_headers = response.info()
 
-    """Add headers to the API call
-
-    :param request_headers: A dictionary of all the request headers
-    :type request_headers: dictionary
-    """
     def _set_headers(self, request_headers):
+        """Build the headers for the request
+
+        :param request_headers: headers to set for the API call
+        :type response: dict
+        :return:
+        """
         if self.request_headers:
             self.request_headers.update(request_headers)
         else:
             self.request_headers = request_headers
 
-    """Make the API call and return the response. This is separated into it's
-       own function, so we can mock it easily for testing.
-    """
     def _make_request(self, opener, request):
+        """Make the API call and return the response. This is separated into
+           it's own function, so we can mock it easily for testing.
+
+        :param opener:
+        :type opener:
+        :param request: url payload to request
+        :type request: urllib.Request object
+        :return:
+        """
         return opener.open(request)
 
-    """Add variable values to the url. (e.g. /your/api/{variable_value}/call)
-       Another example: if you have a Python reserved word, such as global,
-       in your url, you must use this method.
-
-    :param name: Name of the url segment
-    :type name: string
-    """
     def _(self, name):
+        """Add variable values to the url.
+           (e.g. /your/api/{variable_value}/call)
+           Another example: if you have a Python reserved word, such as global,
+           in your url, you must use this method.
+
+        :param name: Name of the url segment
+        :type name: string
+        :return:
+        """
         self._add_to_url_path(name)
         return self
 
-    """Dynamically add method calls to the url, then call a method.
-       (e.g. client.name.name.method())
-       You can also add a version number by using .version(<int>)
-
-    :param name: Name of the url segment or method call
-    :type name: string or integer if name == version
-    """
     def __getattr__(self, name):
+        """Dynamically add method calls to the url, then call a method.
+           (e.g. client.name.name.method())
+           You can also add a version number by using .version(<int>)
+
+        :param name: Name of the url segment or method call
+        :type name: string or integer if name == version
+        :return: mixed
+        """
         if name == 'version':
             def get_version(*args, **kwargs):
+                """
+                :param args: dict of settings
+                :param kwargs: unused
+                :return: string, version
+                """
                 self._version = args[0]
                 return self
             return get_version
@@ -142,6 +161,11 @@ class Client(object):
             method = name.upper()
 
             def http_request(*args, **kwargs):
+                """Make the API call
+                :param args: unused
+                :param kwargs:
+                :return: Client object
+                """
                 if 'request_headers' in kwargs:
                     self._set_headers(kwargs['request_headers'])
                 data = json.dumps(kwargs['request_body']).encode('utf-8')\
@@ -165,12 +189,21 @@ class Client(object):
 
     @property
     def status_code(self):
+        """
+        :return: integer, status code of API call
+        """
         return self._status_code
 
     @property
     def response_body(self):
+        """
+        :return: response from the API
+        """
         return self._response_body
 
     @property
     def response_headers(self):
+        """
+        :return: dict of response headers
+        """
         return self._response_headers
